# remirepo/fedora spec file for php-tecnickcom-tc-lib-pdf-image
#
# SPDX-FileCopyrightText:  Copyright 2023-2025 Remi Collet
# SPDX-License-Identifier: CECILL-2.1
# http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
#
# Please, preserve the changelog entries
#
%global gh_commit    f9bc757b3fe3b8d675ae993404048cceeb037417
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global c_vendor     tecnickcom
%global gh_owner     tecnickcom
%global gh_project   tc-lib-pdf-image
%global php_project  %{_datadir}/php/Com/Tecnick/Pdf/Image
%global with_tests   0%{!?_without_tests:1}

Name:           php-%{gh_owner}-%{gh_project}
Version:        2.1.14
Release:        1%{?dist}
Summary:        PHP library containing PDF Image methods

License:        LGPL-3.0-or-later
URL:            https://github.com/%{gh_owner}/%{gh_project}
Source0:        https://github.com/%{gh_owner}/%{gh_project}/archive/%{gh_commit}/%{name}-%{version}-%{?gh_short}.tar.gz

BuildArch:      noarch
%if %{with_tests}
# For tests
%global phpunit %{_bindir}/phpunit10
BuildRequires:  phpunit10 >= 10.5.40
BuildRequires:  php(language) >= 8.1
BuildRequires:  php-gd
BuildRequires:  php-zlib
BuildRequires: (php-composer(%{c_vendor}/tc-lib-file)        >= 2.2     with php-composer(%{c_vendor}/tc-lib-file)        < 3)
BuildRequires: (php-composer(%{c_vendor}/tc-lib-color)       >= 2.2     with php-composer(%{c_vendor}/tc-lib-color)       < 3)
BuildRequires: (php-composer(%{c_vendor}/tc-lib-pdf-encrypt) >= 2.1     with php-composer(%{c_vendor}/tc-lib-pdf-encrypt) < 3)
%endif
BuildRequires:  php-fedora-autoloader-devel

# From composer.json, "require": {
#    "php": ">=8.1",
#    "ext-gd": "*",
#    "ext-zlib": "*",
#    "tecnickcom/tc-lib-file": "^2.2",
#    "tecnickcom/tc-lib-color": "^2.2",
#    "tecnickcom/tc-lib-pdf-encrypt": "^2.0"
Requires:       php(language) >= 8.1
Requires:       php-gd
Requires:       php-zlib
Requires:      (php-composer(%{c_vendor}/tc-lib-file)        >= 2.2     with php-composer(%{c_vendor}/tc-lib-file)        < 3)
Requires:      (php-composer(%{c_vendor}/tc-lib-color)       >= 2.2     with php-composer(%{c_vendor}/tc-lib-color)       < 3)
Requires:      (php-composer(%{c_vendor}/tc-lib-pdf-encrypt) >= 2.1     with php-composer(%{c_vendor}/tc-lib-pdf-encrypt) < 3)
# From phpcompatinfo report for version 2.0.8
# none
Requires:       php-composer(fedora/autoloader)

# Composer
Provides:       php-composer(%{c_vendor}/%{gh_project}) = %{version}
# Upstream package name
Provides:       php-%{gh_project} = %{version}


%description
PHP library containing PDF Image methods.

The initial source code has been extracted from TCPDF (http://www.tcpdf.org).


%prep
%setup -q -n %{gh_project}-%{gh_commit}

: Sanity check
grep -q '^%{version}$' VERSION


%build
phpab --template fedora --output src/autoload.php src
cat << 'EOF' | tee -a src/autoload.php
\Fedora\Autoloader\Dependencies::required([
    '%{_datadir}/php/Com/Tecnick/File/autoload.php',
    '%{_datadir}/php/Com/Tecnick/Color/autoload.php',
    '%{_datadir}/php/Com/Tecnick/Pdf/Encrypt/autoload.php',
]);
EOF


%install
mkdir -p   $(dirname %{buildroot}%{php_project})
cp -pr src %{buildroot}%{php_project}


%check
%if %{with_tests}
mkdir vendor
cat << 'EOF' | tee vendor/autoload.php
<?php
require '%{buildroot}%{php_project}/autoload.php';
\Fedora\Autoloader\Autoload::addPsr4('Test\\', dirname(__DIR__) . '/test');
EOF

ret=0
for cmdarg in php php81 php82 php83 php84; do
   if which $cmdarg; then
      set $cmdarg
      cp phpunit.xml.dist phpunit.xml
      $1 ${2:-%{phpunit}} --migrate-configuration || :
      $1 ${2:-%{phpunit}} --no-coverage || ret=1
   fi
done
exit $ret
%else
: Test suite disabled
%endif


%files
%license LICENSE
%doc composer.json
%doc *.md
%doc test/images
%{php_project}


%changelog
* Sat Jun  7 2025 Remi Collet <remi@remirepo.net> - 2.1.14-1
- update to 2.1.14 (no change)

* Wed May 28 2025 Remi Collet <remi@remirepo.net> - 2.1.12-1
- update to 2.1.12
- raise dependency on tc-lib-file 2.2

* Wed May 14 2025 Remi Collet <remi@remirepo.net> - 2.1.10-1
- update to 2.1.10 (no change)

* Mon Apr 28 2025 Remi Collet <remi@remirepo.net> - 2.1.8-1
- update to 2.1.8 (no change)

* Fri Feb  7 2025 Remi Collet <remi@remirepo.net> - 2.1.7-1
- update to 2.1.7 (no change)

* Fri Dec 27 2024 Remi Collet <remi@remirepo.net> - 2.1.6-1
- update to 2.1.6
- raise dependency on PHP 8.1

* Mon Dec 23 2024 Remi Collet <remi@remirepo.net> - 2.1.5-1
- update to 2.1.5 (no change)
- re-license spec file to CECILL-2.1

* Mon Nov 25 2024 Remi Collet <remi@remirepo.net> - 2.1.4-1
- update to 2.1.4 (no change)

* Mon Oct 28 2024 Remi Collet <remi@remirepo.net> - 2.1.3-1
- update to 2.1.3 (no change)

* Mon Sep  9 2024 Remi Collet <remi@remirepo.net> - 2.1.2-1
- update to 2.1.2 (no change)

* Mon Aug 19 2024 Remi Collet <remi@remirepo.net> - 2.1.1-1
- update to 2.1.1
- raise dependency on tc-lib-color 2.2

* Thu Aug 15 2024 Remi Collet <remi@remirepo.net> - 2.0.14-1
- update to 2.0.14

* Wed Aug 14 2024 Remi Collet <remi@remirepo.net> - 2.0.13-1
- update to 2.0.13

* Fri Apr 12 2024 Remi Collet <remi@remirepo.net> - 2.0.12-1
- update to 2.0.12

* Thu Nov 30 2023 Remi Collet <remi@remirepo.net> - 2.0.11-1
- update to 2.0.11

* Wed Nov 29 2023 Remi Collet <remi@remirepo.net> - 2.0.10-2
- add images in doc as used by tc-lib-pdf examples
- fix dependency on tc-lib-pdf-encrypt 2.1

* Wed Nov 29 2023 Remi Collet <remi@remirepo.net> - 2.0.10-1
- update to 2.0.10
- raise dependency on tc-lib-pdf-encrypt 2.1

* Tue Nov 28 2023 Remi Collet <remi@remirepo.net> - 2.0.8-1
- initial package, version 2.0.8

